// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: Epxrlcorr
// Author: Richard Saxton 
//
// Description: Main class for calculating  a source fluxer profile
//
// Modifications: See ChangeLog
//

#ifndef Epxrlcorr_H
#define Epxrlcorr_H

/* General classes */
#include <iostream>

/* SAS-specific classes */
#include "Tracer.h"
#include "Dal.h"
#include "Image.h"

/* Local Structure */


/****************************************************
 *
 * class Epxrlcorr
 *
 ***************************************************/

class Epxrlcorr
{
public:

  /* Constructor */
  Epxrlcorr();

  /* Destructor */
  ~Epxrlcorr();

private:
  /* Member fields */
  /* Methods */
   void readRawEventFile(string eventset);

   string findOffsetMap();

   SImage calculateXRL(string &offsetmap);

   short int getmedian(vector<short int> tempVec);

   void XRLCorrApply(DataSet * evset, SImage XRLCorrMap);

   bool _rawinputfile; // True if input from a raw event file and false
		  // if from an epframes output file

   void MakeXRLimage(string xrlimage, SImage XRLCorrMap, DataSet * evset);

   void writeKeywords(DataSet * evset, DataSet * xrlset);
};

#endif

